var languageNames = {
"en-US": "İngilizce (ABD)",
"sq": "Arnavutça",
"am": "Amharca",
"ar": "Arapça",
"ast": "Asturyaca",
"bn": "Bengalce",
"bn-IN": "Bengalce (Hindistan)",
"bs": "Boşnakça",
"bg": "Bulgarca",
"ca": "Katalanca",
"ca-valencia": "Katalanca (Valensiya)",
"zh-CN": "Çince (Basitleştirilmiş)",
"zh-TW": "Çince (Geleneksel)",
"hr": "Hırvatça",
"cs": "Çekce",
"da": "Danish",
"nl": "Dutch",
"dz": "Dzongkha",
"en-GB": "English (UK)",
"en-ZA": "English (SA)",
"eo": "Esperanto",
"et": "Estonian",
"eu": "Basque",
"fi": "Finnish",
"fr": "French",
"gl": "Galician",
"ka": "Georgian",
"de": "Almanca",
"el": "Yunanca",
"gu": "Gujarati",
"he": "İbranice",
"hi": "Hintçe",
"hu": "Macarca",
"id": "Endonezce",
"is": "İzlandaca",
"it": "İtalyanca",
"ja": "Japonca",
"km": "Kmerce",
"ko": "Korece",
"lo": "Lao",
"lv": "Latvian",
"lt": "Lithuanian",
"mk": "Macedonian",
"ne": "Nepali",
"nn": "Norwegian Nynorsk",
"nb": "Norwegian Bokmål",
"om": "Oromo",
"pl": "Polish",
"pt": "Portuguese",
"pt-BR": "Portuguese (Brazil)",
"ro": "Romanian",
"ru": "Russian",
"sid": "Sidama",
"si": "Sinhala",
"sk": "Slovak",
"sl": "Slovenian",
"dsb": "Sorbian (Lower)",
"hsb": "Sorbian (Upper)",
"es": "Spanish",
"sv": "Swedish",
"tg": "Tajik",
"ta": "Tamil",
"bo": "Tibetan",
"tr": "Turkish",
"ug": "Uyghur",
"uk": "Ukrainian",
"vi": "Vietnamese",
};
